@@ -5,7 +5,7 @@ RSpec.describe JWT do
     let(:keypair)       { OpenSSL::PKey::RSA.new(2048) }
     let(:jwk)           { JWT::JWK.new(keypair) }
     let(:public_jwks) { { keys: [jwk.export, { kid: 'not_the_correct_one' }] } }
-    let(:token_payload) { {'data' => 'something'} }
+    let(:token_payload) { { 'data' => 'something' } }
     let(:token_headers) { { kid: jwk.kid } }
     let(:signed_token)  { described_class.encode(token_payload, jwk.keypair, 'RS512', token_headers) }
 
@@ -21,7 +21,7 @@ RSpec.describe JWT do
     context 'when jwk keys are given as an array' do
       context 'and kid is in the set' do
         it 'is able to decode the token' do
-          payload, _header = described_class.decode(signed_token, nil, true, { algorithms: ['RS512'], jwks: public_jwks})
+          payload, _header = described_class.decode(signed_token, nil, true, { algorithms: ['RS512'], jwks: public_jwks })
           expect(payload).to eq(token_payload)
         end
       end
@@ -31,16 +31,16 @@ RSpec.describe JWT do
           public_jwks[:keys].first[:kid] = 'NOT_A_MATCH'
         end
         it 'raises an exception' do
-          expect { described_class.decode(signed_token, nil, true, { algorithms: ['RS512'], jwks: public_jwks}) }.to raise_error(
+          expect { described_class.decode(signed_token, nil, true, { algorithms: ['RS512'], jwks: public_jwks }) }.to raise_error(
             JWT::DecodeError, /Could not find public key for kid .*/
           )
         end
       end
 
       context 'no keys are found in the set' do
-        let(:public_jwks) { {keys: []} }
+        let(:public_jwks) { { keys: [] } }
         it 'raises an exception' do
-          expect { described_class.decode(signed_token, nil, true, { algorithms: ['RS512'], jwks: public_jwks}) }.to raise_error(
+          expect { described_class.decode(signed_token, nil, true, { algorithms: ['RS512'], jwks: public_jwks }) }.to raise_error(
             JWT::DecodeError, /No keys found in jwks/
           )
         end
@@ -49,7 +49,7 @@ RSpec.describe JWT do
       context 'token does not know the kid' do
         let(:token_headers) { {} }
         it 'raises an exception' do
-          expect { described_class.decode(signed_token, nil, true, { algorithms: ['RS512'], jwks: public_jwks}) }.to raise_error(
+          expect { described_class.decode(signed_token, nil, true, { algorithms: ['RS512'], jwks: public_jwks }) }.to raise_error(
             JWT::DecodeError, 'No key id (kid) found from token headers'
           )
         end
@@ -58,7 +58,7 @@ RSpec.describe JWT do
 
     context 'when jwk keys are loaded using a proc/lambda' do
       it 'decodes the token' do
-        payload, _header = described_class.decode(signed_token, nil, true, { algorithms: ['RS512'], jwks: lambda { |_opts| public_jwks }})
+        payload, _header = described_class.decode(signed_token, nil, true, { algorithms: ['RS512'], jwks: lambda { |_opts| public_jwks } })
         expect(payload).to eq(token_payload)
       end
     end
@@ -66,15 +66,15 @@ RSpec.describe JWT do
     context 'when jwk keys are rotated' do
       it 'decodes the token' do
         key_loader = ->(options) { options[:invalidate] ? public_jwks : { keys: [] } }
-        payload, _header = described_class.decode(signed_token, nil, true, { algorithms: ['RS512'], jwks: key_loader})
+        payload, _header = described_class.decode(signed_token, nil, true, { algorithms: ['RS512'], jwks: key_loader })
         expect(payload).to eq(token_payload)
       end
     end
 
     context 'when jwk keys are loaded from JSON with string keys' do
       it 'decodes the token' do
-        key_loader = ->(options) { JSON.parse(JSON.generate(public_jwks)) }
-        payload, _header = described_class.decode(signed_token, nil, true, { algorithms: ['RS512'], jwks: key_loader})
+        key_loader = ->(_options) { JSON.parse(JSON.generate(public_jwks)) }
+        payload, _header = described_class.decode(signed_token, nil, true, { algorithms: ['RS512'], jwks: key_loader })
         expect(payload).to eq(token_payload)
       end
     end
@@ -87,7 +87,7 @@ RSpec.describe JWT do
       let(:jwks)               { { keys: [hmac_jwk.export(include_private: true), rsa_jwk.export, ec_jwk_secp384r1.export, ec_jwk_secp521r1.export] } }
 
       context 'when RSA key is pointed to as HMAC secret' do
-        let(:signed_token) { described_class.encode({'foo' => 'bar'}, 'is not really relevant in the scenario', 'HS256', { kid: rsa_jwk.kid }) }
+        let(:signed_token) { described_class.encode({ 'foo' => 'bar' }, 'is not really relevant in the scenario', 'HS256', { kid: rsa_jwk.kid }) }
 
         it 'fails in some way' do
           expect { described_class.decode(signed_token, nil, true, algorithms: ['HS256'], jwks: jwks) }.to(
@@ -105,7 +105,7 @@ RSpec.describe JWT do
       end
 
       context 'when EC key is pointed to as HMAC secret' do
-        let(:signed_token) { described_class.encode({'foo' => 'bar'}, 'is not really relevant in the scenario', 'HS256', { kid: ec_jwk_secp384r1.kid }) }
+        let(:signed_token) { described_class.encode({ 'foo' => 'bar' }, 'is not really relevant in the scenario', 'HS256', { kid: ec_jwk_secp384r1.kid }) }
 
         it 'fails in some way' do
           expect { described_class.decode(signed_token, nil, true, algorithms: ['HS256'], jwks: jwks) }.to(
@@ -123,7 +123,7 @@ RSpec.describe JWT do
       end
 
       context 'when EC key is pointed to as RSA public key' do
-        let(:signed_token) { described_class.encode({'foo' => 'bar'}, rsa_jwk.keypair, 'RS512', { kid: ec_jwk_secp384r1.kid }) }
+        let(:signed_token) { described_class.encode({ 'foo' => 'bar' }, rsa_jwk.keypair, 'RS512', { kid: ec_jwk_secp384r1.kid }) }
 
         it 'fails in some way' do
           expect { described_class.decode(signed_token, nil, true, algorithms: ['RS512'], jwks: jwks) }.to(
@@ -133,27 +133,27 @@ RSpec.describe JWT do
       end
 
       context 'when HMAC secret is pointed to as RSA public key' do
-        let(:signed_token) { described_class.encode({'foo' => 'bar'}, rsa_jwk.keypair, 'RS512', { kid: hmac_jwk.kid }) }
+        let(:signed_token) { described_class.encode({ 'foo' => 'bar' }, rsa_jwk.keypair, 'RS512', { kid: hmac_jwk.kid }) }
 
         it 'fails in some way' do
           expect { described_class.decode(signed_token, nil, true, algorithms: ['RS512'], jwks: jwks) }.to(
-            raise_error(NoMethodError, /undefined method `verify' for \"secret\":String/)
+            raise_error(NoMethodError, /undefined method `verify' for "secret":String/)
           )
         end
       end
 
       context 'when HMAC secret is pointed to as EC public key' do
-        let(:signed_token) { described_class.encode({'foo' => 'bar'}, ec_jwk_secp384r1.keypair, 'ES384', { kid: hmac_jwk.kid }) }
+        let(:signed_token) { described_class.encode({ 'foo' => 'bar' }, ec_jwk_secp384r1.keypair, 'ES384', { kid: hmac_jwk.kid }) }
 
         it 'fails in some way' do
           expect { described_class.decode(signed_token, nil, true, algorithms: ['ES384'], jwks: jwks) }.to(
-            raise_error(NoMethodError, /undefined method `group' for \"secret\":String/)
+            raise_error(NoMethodError, /undefined method `group' for "secret":String/)
           )
         end
       end
 
       context 'when ES384 key is pointed to as ES512 key' do
-        let(:signed_token) { described_class.encode({'foo' => 'bar'}, ec_jwk_secp384r1.keypair, 'ES512', { kid: ec_jwk_secp521r1.kid }) }
+        let(:signed_token) { described_class.encode({ 'foo' => 'bar' }, ec_jwk_secp384r1.keypair, 'ES512', { kid: ec_jwk_secp521r1.kid }) }
 
         it 'fails in some way' do
           expect { described_class.decode(signed_token, nil, true, algorithms: ['ES512'], jwks: jwks) }.to(
