@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 RSpec.describe JWT::JWK::EC do
-  let(:ec_key) { OpenSSL::PKey::EC.new("secp384r1").generate_key }
+  let(:ec_key) { OpenSSL::PKey::EC.new('secp384r1').generate_key }
 
   describe '.new' do
     subject { described_class.new(keypair) }
@@ -18,6 +18,7 @@ RSpec.describe JWT::JWK::EC do
       let(:keypair) { OpenSSL::PKey::EC.new(ec_key.public_key.group).tap { |ec| ec.public_key = ec_key.public_key } }
       it 'creates an instance of the class' do
         expect(subject).to be_a described_class
+        expect(subject.private?).to eq false
       end
     end
   end
@@ -75,7 +76,7 @@ RSpec.describe JWT::JWK::EC do
     let(:include_private) { false }
     let(:exported_key) { described_class.new(keypair).export(include_private: include_private) }
 
-    ['P-256', 'P-384', 'P-521'].each do |crv|
+    ['P-256', 'P-384', 'P-521', 'P-256K'].each do |crv|
       context "when crv=#{crv}" do
         let(:openssl_curve) { JWT::JWK::EC.to_openssl_curve(crv) }
         let(:ec_key) { OpenSSL::PKey::EC.new(openssl_curve).generate_key }
@@ -90,7 +91,7 @@ RSpec.describe JWT::JWK::EC do
             expect(subject).to be_a described_class
 
             # Regular export returns only the non-private parts.
-            public_only = exported_key.select{ |k, v| k != :d }
+            public_only = exported_key.reject { |k, _v| k == :d }
             expect(subject.export).to eq(public_only)
 
             # Private export returns the original input.
