@@ -4,7 +4,7 @@ RSpec.describe JWT do
   let(:payload) { { 'user_id' => 'some@user.tld' } }
 
   let :data do
-   data = {
+    data = {
       :empty_token => 'e30K.e30K.e30K',
       :secret => 'My$ecretK3y',
       :rsa_private => OpenSSL::PKey.read(File.read(File.join(CERT_PATH, 'rsa-2048-private.pem'))),
@@ -17,6 +17,8 @@ RSpec.describe JWT do
       'ES384_public' => OpenSSL::PKey.read(File.read(File.join(CERT_PATH, 'ec384-public.pem'))),
       'ES512_private' => OpenSSL::PKey.read(File.read(File.join(CERT_PATH, 'ec512-private.pem'))),
       'ES512_public' => OpenSSL::PKey.read(File.read(File.join(CERT_PATH, 'ec512-public.pem'))),
+      'ES256K_private' => OpenSSL::PKey.read(File.read(File.join(CERT_PATH, 'ec256k-private.pem'))),
+      'ES256K_public' => OpenSSL::PKey.read(File.read(File.join(CERT_PATH, 'ec256k-public.pem'))),
       'NONE' => 'eyJhbGciOiJub25lIn0.eyJ1c2VyX2lkIjoic29tZUB1c2VyLnRsZCJ9.',
       'HS256' => 'eyJhbGciOiJIUzI1NiJ9.eyJ1c2VyX2lkIjoic29tZUB1c2VyLnRsZCJ9.kWOVtIOpWcG7JnyJG0qOkTDbOy636XrrQhMm_8JrRQ8',
       'HS512256' => 'eyJhbGciOiJIUzUxMjI1NiJ9.eyJ1c2VyX2lkIjoic29tZUB1c2VyLnRsZCJ9.Ds_4ibvf7z4QOBoKntEjDfthy3WJ-3rKMspTEcHE2bA',
@@ -37,10 +39,10 @@ RSpec.describe JWT do
       ed25519_private = RbNaCl::Signatures::Ed25519::SigningKey.new('abcdefghijklmnopqrstuvwxyzABCDEF')
       ed25519_public =  ed25519_private.verify_key
       data.merge!(
-        'ED25519_private' =>  ed25519_private,
+        'ED25519_private' => ed25519_private,
         'ED25519_public' => ed25519_public,
-        'EdDSA_private' =>  ed25519_private,
-        'EdDSA_public' => ed25519_public,
+        'EdDSA_private' => ed25519_private,
+        'EdDSA_public' => ed25519_public
       )
     end
     data
@@ -102,20 +104,20 @@ RSpec.describe JWT do
 
   context 'payload validation' do
     it 'validates the payload with the ClaimsValidator if the payload is a hash' do
-      validator = double()
+      validator = double
       expect(JWT::ClaimsValidator).to receive(:new) { validator }
       expect(validator).to receive(:validate!) { true }
 
       payload = {}
-      JWT.encode payload, "secret", 'HS256'
+      JWT.encode payload, 'secret', 'HS256'
     end
 
     it 'does not validate the payload if it is not present' do
-      validator = double()
+      validator = double
       expect(JWT::ClaimsValidator).not_to receive(:new) { validator }
 
       payload = nil
-      JWT.encode payload, "secret", 'HS256'
+      JWT.encode payload, 'secret', 'HS256'
     end
   end
 
@@ -229,7 +231,7 @@ RSpec.describe JWT do
     end
   end
 
-  %w[ES256 ES384 ES512].each do |alg|
+  %w[ES256 ES384 ES512 ES256K].each do |alg|
     context "alg: #{alg}" do
       before(:each) do
         data[alg] = JWT.encode payload, data["#{alg}_private"], alg
@@ -265,18 +267,7 @@ RSpec.describe JWT do
     end
   end
 
-  unless ::Gem::Version.new(OpenSSL::VERSION) >= ::Gem::Version.new('2.1')
-    %w[PS256 PS384 PS512].each do |alg|
-      context "alg: #{alg}" do
-        it 'raises error about OpenSSL version' do
-          expect { JWT.encode payload, data[:rsa_private], alg }.to raise_error(
-            JWT::RequiredDependencyError,
-            /You currently have OpenSSL .*. PS support requires >= 2.1/
-          )
-        end
-      end
-    end
-  else
+  if ::Gem::Version.new(OpenSSL::VERSION) >= ::Gem::Version.new('2.1')
     %w[PS256 PS384 PS512].each do |alg|
       context "alg: #{alg}" do
         before(:each) do
@@ -297,10 +288,10 @@ RSpec.describe JWT do
           translated_alg  = alg.gsub('PS', 'sha')
           valid_signature = data[:rsa_public].verify_pss(
             translated_alg,
-            JWT::Base64.url_decode(signature),
+            Base64.urlsafe_decode64(signature),
             [header, body].join('.'),
             salt_length: :auto,
-            mgf1_hash:   translated_alg
+            mgf1_hash: translated_alg
           )
           expect(valid_signature).to be true
         end
@@ -325,6 +316,17 @@ RSpec.describe JWT do
         end
       end
     end
+  else
+    %w[PS256 PS384 PS512].each do |alg|
+      context "alg: #{alg}" do
+        it 'raises error about OpenSSL version' do
+          expect { JWT.encode payload, data[:rsa_private], alg }.to raise_error(
+            JWT::RequiredDependencyError,
+            /You currently have OpenSSL .*. PS support requires >= 2.1/
+          )
+        end
+      end
+    end
   end
 
   context 'Invalid' do
@@ -357,6 +359,118 @@ RSpec.describe JWT do
   end
 
   context 'Verify' do
+    context 'when key given as an array with multiple possible keys' do
+      let(:payload) { { 'data' => 'data' } }
+      let(:token)   { JWT.encode(payload, secret, 'HS256') }
+      let(:secret)  { 'hmac_secret' }
+
+      it 'should be able to verify signature when block returns multiple keys' do
+        decoded_token = JWT.decode(token, nil, true, { algorithm: 'HS256' }) do
+          ['not_the_secret', secret]
+        end
+        expect(decoded_token.first).to eq(payload)
+      end
+
+      it 'should be able to verify signature when multiple keys given as a parameter' do
+        decoded_token = JWT.decode(token, ['not_the_secret', secret], true, { algorithm: 'HS256' })
+        expect(decoded_token.first).to eq(payload)
+      end
+
+      it 'should fail if only invalid keys are given' do
+        expect do
+          JWT.decode(token, ['not_the_secret', 'not_the_secret_2'], true, { algorithm: 'HS256' })
+        end.to raise_error(JWT::VerificationError, 'Signature verification failed')
+      end
+    end
+
+    context 'when encoded payload is used to extract key through find_key' do
+      it 'should be able to find a key using the block passed to decode' do
+        payload_data = { key: 'secret' }
+        token = JWT.encode payload_data, data[:secret], 'HS256'
+
+        expect do
+          JWT.decode(token, nil, true, { algorithm: 'HS256' }) do |_headers, payload|
+            data[payload['key'].to_sym]
+          end
+        end.not_to raise_error
+      end
+
+      it 'should be able to verify signature when block returns multiple keys' do
+        iss = 'My_Awesome_Company'
+        iss_payload = { data: 'data', iss: iss }
+
+        secrets = { iss => ['hmac_secret2', data[:secret]] }
+
+        token = JWT.encode iss_payload, data[:secret], 'HS256'
+
+        expect do
+          JWT.decode(token, nil, true, { iss: iss, verify_iss: true, algorithm: 'HS256' }) do |_headers, payload|
+            secrets[payload['iss']]
+          end
+        end.not_to raise_error
+      end
+
+      it 'should be able to find a key using the block passed to decode with iss verification' do
+        iss = 'My_Awesome_Company'
+        iss_payload = { data: 'data', iss: iss }
+
+        secrets = { iss => data[:secret] }
+
+        token = JWT.encode iss_payload, data[:secret], 'HS256'
+
+        expect do
+          JWT.decode(token, nil, true, { iss: iss, verify_iss: true, algorithm: 'HS256' }) do |_headers, payload|
+            secrets[payload['iss']]
+          end
+        end.not_to raise_error
+      end
+
+      it 'should be able to verify signature when block returns multiple keys with iss verification' do
+        iss = 'My_Awesome_Company'
+        iss_payload = { data: 'data', iss: iss }
+
+        secrets = { iss => ['hmac_secret2', data[:secret]] }
+
+        token = JWT.encode iss_payload, data[:secret], 'HS256'
+
+        expect do
+          JWT.decode(token, nil, true, { iss: iss, verify_iss: true, algorithm: 'HS256' }) do |_headers, payload|
+            secrets[payload['iss']]
+          end
+        end.not_to raise_error
+      end
+
+      it 'should be able to find a key using a block with multiple issuers' do
+        issuers = %w[My_Awesome_Company1 My_Awesome_Company2]
+        iss_payload = { data: 'data', iss: issuers.first }
+
+        secrets = { issuers.first => data[:secret], issuers.last => 'hmac_secret2' }
+
+        token = JWT.encode iss_payload, data[:secret], 'HS256'
+
+        expect do
+          JWT.decode(token, nil, true, { iss: issuers, verify_iss: true, algorithm: 'HS256' }) do |_headers, payload|
+            secrets[payload['iss']]
+          end
+        end.not_to raise_error
+      end
+
+      it 'should be able to verify signature when block returns multiple keys with multiple issuers' do
+        issuers = %w[My_Awesome_Company1 My_Awesome_Company2]
+        iss_payload = { data: 'data', iss: issuers.first }
+
+        secrets = { issuers.first => [data[:secret], 'hmac_secret1'], issuers.last => 'hmac_secret2' }
+
+        token = JWT.encode iss_payload, data[:secret], 'HS256'
+
+        expect do
+          JWT.decode(token, nil, true, { iss: issuers, verify_iss: true, algorithm: 'HS256' }) do |_headers, payload|
+            secrets[payload['iss']]
+          end
+        end.not_to raise_error
+      end
+    end
+
     context 'algorithm' do
       it 'should raise JWT::IncorrectAlgorithm on mismatch' do
         token = JWT.encode payload, data[:secret], 'HS256'
@@ -374,13 +488,13 @@ RSpec.describe JWT do
         token = JWT.encode payload, data[:rsa_private], 'RS256'
 
         expect do
-          JWT.decode(token, nil, true, { algorithms: ['RS384'] }) do |_,_|
+          JWT.decode(token, nil, true, { algorithms: ['RS384'] }) do |_, _|
             # unsuccessful keyfinder public key network call here
           end
         end.to raise_error JWT::IncorrectAlgorithm
 
         expect do
-          JWT.decode(token, nil, true, { 'algorithms' => ['RS384'] }) do |_,_|
+          JWT.decode(token, nil, true, { 'algorithms' => ['RS384'] }) do |_, _|
             # unsuccessful keyfinder public key network call here
           end
         end.to raise_error JWT::IncorrectAlgorithm
@@ -450,7 +564,7 @@ RSpec.describe JWT do
 
   context 'a token with not enough segments' do
     it 'raises JWT::DecodeError' do
-      token = JWT.encode('ThisIsNotAValidJWTToken', 'secret').split('.').slice(1,2).join
+      token = JWT.encode('ThisIsNotAValidJWTToken', 'secret').split('.').slice(1, 2).join
       expect { JWT.decode(token, nil, true) }.to raise_error(JWT::DecodeError, 'Not enough or too many segments')
     end
   end
@@ -461,16 +575,15 @@ RSpec.describe JWT do
     end
   end
 
-  context 'a token with two segments but does not require verifying' do
-    it 'raises something else than "Not enough or too many segments"' do
-      expect { JWT.decode('ThisIsNotAValidJWTToken.second', nil, false) }.to raise_error(JWT::DecodeError, 'Invalid segment encoding')
+  context 'a token with invalid Base64 segments' do
+    it 'raises JWT::DecodeError' do
+      expect { JWT.decode('hello.there.world') }.to raise_error(JWT::DecodeError, 'Invalid segment encoding')
     end
   end
 
-  context 'Base64' do
-    it 'urlsafe replace + / with - _' do
-      allow(Base64).to receive(:encode64) { 'string+with/non+url-safe/characters_' }
-      expect(JWT::Base64.url_encode('foo')).to eq('string-with_non-url-safe_characters_')
+  context 'a token with two segments but does not require verifying' do
+    it 'raises something else than "Not enough or too many segments"' do
+      expect { JWT.decode('ThisIsNotAValidJWTToken.second', nil, false) }.to raise_error(JWT::DecodeError, 'Invalid segment encoding')
     end
   end
 
@@ -497,20 +610,19 @@ RSpec.describe JWT do
   end
 
   context 'when the alg value is given as a header parameter' do
-
     it 'does not override the actual algorithm used' do
-      headers = JSON.parse(::JWT::Base64.url_decode(JWT.encode('Hello World', 'secret', 'HS256', { alg: 'HS123'}).split('.').first))
+      headers = JSON.parse(Base64.urlsafe_decode64(JWT.encode('Hello World', 'secret', 'HS256', { alg: 'HS123' }).split('.').first))
       expect(headers['alg']).to eq('HS256')
     end
 
-    it "should generate the same token" do
-      expect(JWT.encode('Hello World', 'secret', 'HS256', { alg: 'HS256'})).to eq JWT.encode('Hello World', 'secret', 'HS256')
+    it 'should generate the same token' do
+      expect(JWT.encode('Hello World', 'secret', 'HS256', { alg: 'HS256' })).to eq JWT.encode('Hello World', 'secret', 'HS256')
     end
   end
 
   context 'when hmac algorithm is used without secret key' do
     it 'encodes payload' do
-      payload = { a: 1, b: 'b'}
+      payload = { a: 1, b: 'b' }
 
       token = JWT.encode(payload, '', 'HS256')
 
@@ -526,13 +638,13 @@ RSpec.describe JWT do
 
     it 'ignores algorithm casing during encode/decode' do
       enc = JWT.encode(payload, '', 'hs256')
-      expect(JWT.decode(enc, '')).to eq([payload, { 'alg' => 'HS256'}])
+      expect(JWT.decode(enc, '')).to eq([payload, { 'alg' => 'HS256' }])
 
       enc = JWT.encode(payload, data[:rsa_private], 'rs512')
-      expect(JWT.decode(enc, data[:rsa_public], true, algorithm: 'RS512')).to eq([payload, { 'alg' => 'RS512'}])
+      expect(JWT.decode(enc, data[:rsa_public], true, algorithm: 'RS512')).to eq([payload, { 'alg' => 'RS512' }])
 
       enc = JWT.encode(payload, data[:rsa_private], 'RS512')
-      expect(JWT.decode(enc, data[:rsa_public], true, algorithm: 'rs512')).to eq([payload, { 'alg' => 'RS512'}])
+      expect(JWT.decode(enc, data[:rsa_public], true, algorithm: 'rs512')).to eq([payload, { 'alg' => 'RS512' }])
     end
 
     it 'raises error for invalid algorithm' do
@@ -544,7 +656,7 @@ RSpec.describe JWT do
 
   describe '::JWT.decode with verify_iat parameter' do
     let!(:time_now) { Time.now }
-    let(:token)     { ::JWT.encode({ pay: 'load', iat: iat}, 'secret', 'HS256') }
+    let(:token)     { ::JWT.encode({ pay: 'load', iat: iat }, 'secret', 'HS256') }
 
     subject(:decoded_token) { ::JWT.decode(token, 'secret', true, verify_iat: true) }
 
@@ -571,4 +683,76 @@ RSpec.describe JWT do
       end
     end
   end
+
+  describe '::JWT.decode with x5c parameter' do
+    let(:alg) { 'RS256' }
+    let(:root_certificates) { [instance_double('OpenSSL::X509::Certificate')] }
+    let(:key_finder) { instance_double('::JWT::X5cKeyFinder') }
+
+    before do
+      expect(::JWT::X5cKeyFinder).to receive(:new).with(root_certificates, nil).and_return(key_finder)
+      expect(key_finder).to receive(:from).and_return(data[:rsa_public])
+    end
+    subject(:decoded_token) { ::JWT.decode(data[alg], nil, true, algorithm: alg, x5c: { root_certificates: root_certificates }) }
+
+    it 'calls X5cKeyFinder#from to verify the signature and return the payload' do
+      jwt_payload, header = decoded_token
+
+      expect(header['alg']).to eq alg
+      expect(jwt_payload).to eq payload
+    end
+  end
+
+  describe 'when keyfinder given with 1 argument' do
+    let(:token) { JWT.encode(payload, 'HS256', 'HS256') }
+    it 'decodes the token' do
+      expect(JWT.decode(token, nil, true, algorithm: 'HS256') { |header| header['alg'] }).to include(payload)
+    end
+  end
+
+  describe 'when keyfinder given with 2 arguments' do
+    let(:token) { JWT.encode(payload, payload['user_id'], 'HS256') }
+    it 'decodes the token' do
+      expect(JWT.decode(token, nil, true, algorithm: 'HS256') { |_header, payload| payload['user_id'] }).to include(payload)
+    end
+  end
+
+  describe 'when keyfinder given with 3 arguments' do
+    let(:token) { JWT.encode(payload, 'HS256', 'HS256') }
+    it 'decodes the token but does not pass the payload' do
+      expect(JWT.decode(token, nil, true, algorithm: 'HS256') do |header, token_payload, nothing|
+        expect(token_payload).to eq(nil)  # This behaviour is not correct, the payload should be available in the keyfinder
+        expect(nothing).to eq(nil)
+        header['alg']
+      end).to include(payload)
+    end
+  end
+
+  describe 'when none token is and decoding without key and with verification' do
+    let(:none_token) { ::JWT.encode(payload, nil, 'none') }
+    it 'decodes the token' do
+      expect(::JWT.decode(none_token, nil, true, algorithms: 'none')).to eq([payload, { 'alg' => 'none' }])
+    end
+  end
+
+  describe 'when none token is decoded with a key given' do
+    let(:none_token) { ::JWT.encode(payload, nil, 'none') }
+    it 'decodes the token' do
+      expect(::JWT.decode(none_token, 'key', true, algorithms: 'none')).to eq([payload, { 'alg' => 'none' }])
+    end
+  end
+
+  describe 'when none token is decoded without verify' do
+    let(:none_token) { ::JWT.encode(payload, nil, 'none') }
+    it 'decodes the token' do
+      expect(::JWT.decode(none_token, 'key', false)).to eq([payload, { 'alg' => 'none' }])
+    end
+  end
+
+  describe 'when token signed with nil and decoded with nil' do
+    let(:no_key_token) { ::JWT.encode(payload, nil, 'HS512') }
+    it 'raises JWT::DecodeError' do
+      expect { ::JWT.decode(no_key_token, nil, true, algorithms: 'HS512') }.to raise_error(JWT::DecodeError, 'No verification key available')
+    end
+  end
 end
